pyasge.MOUSE
=====================

.. currentmodule:: pyasge.MOUSE
.. autosummary::
   :toctree: _generate

.. autodata:: pyasge.MOUSE
   :noindex:

Actions
########
.. autoattribute:: pyasge.MOUSE.BUTTON_PRESSED
.. autoattribute:: pyasge.MOUSE.BUTTON_RELEASED

Buttons
#######
.. autoattribute:: pyasge.MOUSE.MOUSE_BTN1
.. autoattribute:: pyasge.MOUSE.MOUSE_BTN2
.. autoattribute:: pyasge.MOUSE.MOUSE_BTN3
.. autoattribute:: pyasge.MOUSE.MOUSE_BTN4
.. autoattribute:: pyasge.MOUSE.MOUSE_BTN5
